
********************************************************
* Purpose:Move LaserJet Cursor by Rows and Columns
* Category:Laserjet Functions
* Section:2. LaserJet
* Copyright: 1993 SCT Associates, Inc
* Author: Steve Tyrakowski/Kevin Maher
*
* Description:
*    This function allows you to position the PCL cursor
*    in the LaserJet to the Row/Column position.
*
*    Positioning may be absolute or relative.
*
* Syntax:
*    LJ_GoRC([<xRow>], [<xCol>]) => cEscCodes
*
* Formal Arguments:
*   [<xRow>] row to go
*   [<xCol>] col to go
*
*     Note that these parameters may be number or character.
*     if they are character, then they are used as-is where the
*     row or col gets specified.  This allows for relative
*     positioning by using the + or - in front of the number.
*
* Returns:
*     Character string containing printer escape codes
*
* See Also:
*     LJ_VLine() LJ_HLine() LJ_Rec() LJ_Run() LJ_Box()
********************************************************


FUNCTION LJ_GoRC
PARAMETERS xRow, xCol
PRIVATE cReturn, cRow, cCol

  DO CASE
    CASE Type("xRow") == "C"
      cRow = xRow
    CASE Type("xRow") == "N"
      cRow = AllTrim(Str(xRow))
    OTHERWISE
      cRow = ""
  ENDCASE

  DO CASE
    CASE Type("xCol") == "C"
      cCol = xCol
    CASE Type("xCol") == "N"
      cCol = AllTrim(Str(xCol))
    OTHERWISE
      cCol = ""
  ENDCASE


  IF Empty(cRow) .AND. Empty(cCol)
    cReturn = ""
  ELSE
    cReturn = "&a"
    DO CASE
      CASE Empty(cRow)
        cReturn = cReturn + cCol+"C"
      CASE Empty(cCol)
        cReturn = cReturn + cRow+"R"
      OTHERWISE
        cReturn = cReturn + cRow+"r"+cCol+"C"
    ENDCASE
  ENDIF

RETURN cReturn
