
* 
* Purpose: Start and stop recording a printer macro
* Author: Kevin Maher/Steve Tyrakowski
* Copyright: 1993 SCT Associates, Inc.
* 
* Section:2. LaserJet
* Category:Laserjet Macros
*
* Syntax:
*          LJ_Rec( nMacro ) => cEscCodes
*
* Parameters:
*      <nMacro> number of printer macro to start recording
*          leave it NIL to stop recording.  Note that there may only
*          be 32 macros stored in the printer's memory at one time
*          The number itself can be larger than 32.
*
* Returns:
*          Character string containing printer escape codes
*          to to define macro
*
* Description:
*          This function will control the starting and stopping of
*          the LaserJet PCL record mode. If a number is passed as
*          a parameter, that will be the macro ID number to start
*          recording.  If no parameter is passed, it will signal
*          the end of macro recording.
*
*          Note that there is no error checking to see if you are
*          currently recording a macro.
*
* Examples:
*
* See Also:
*         LJ_VLINE() LJ_HLINE() LJ_GoTo() LJ_Run() LJ_BOX()
*
* Revisions:
*
* 

FUNCTION LJ_Rec
PARAMETERS nMacro
PRIVATE pCnt, cReturn
  pCnt = Parameters()
  IF pCnt = 0
    cReturn = "&f1X"
  ELSE
    cReturn = "&f"+Alltrim(Str(nMacro))+"y0X"
  ENDIF
RETURN cReturn
